Index: trunk/MagicSoft/Mars/Changelog
===================================================================
--- trunk/MagicSoft/Mars/Changelog	(revision 3607)
+++ trunk/MagicSoft/Mars/Changelog	(revision 3608)
@@ -38,4 +38,7 @@
    * mcalib/MCalibrationChargePix.[h,cc]
      - move consistency checks from Pix to Calc
+
+   * mcalib/MHGausEvents.[h,cc]
+     - fixed axes for event and fourier spectrum Draw
 
 
Index: trunk/MagicSoft/Mars/mcalib/MHGausEvents.cc
===================================================================
--- trunk/MagicSoft/Mars/mcalib/MHGausEvents.cc	(revision 3607)
+++ trunk/MagicSoft/Mars/mcalib/MHGausEvents.cc	(revision 3608)
@@ -497,5 +497,5 @@
   const Int_t n = fEvents.GetSize();
 
-  fGraphEvents = new TGraph(n,CreateXaxis(n),fEvents.GetArray());  
+  fGraphEvents = new TGraph(n,CreateEventXaxis(n),fEvents.GetArray());  
   fGraphEvents->SetTitle("Evolution of Events with time");
   fGraphEvents->GetXaxis()->SetTitle((fEventFrequency) ? "Time [s]" : "Event Nr.");
@@ -514,5 +514,5 @@
   const Int_t n = fPowerSpectrum->GetSize();
 
-  fGraphPowerSpectrum = new TGraph(n,CreateXaxis(n),fPowerSpectrum->GetArray());  
+  fGraphPowerSpectrum = new TGraph(n,CreatePSDXaxis(n),fPowerSpectrum->GetArray());  
   fGraphPowerSpectrum->SetTitle("Power Spectrum Density");
   fGraphPowerSpectrum->GetXaxis()->SetTitle((fEventFrequency) ? "Frequency [Hz]" : "Frequency");
@@ -522,7 +522,7 @@
 // -----------------------------------------------------------------------------
 // 
-// Create the x-axis for the graph
-//
-Float_t *MHGausEvents::CreateXaxis(Int_t n)
+// Create the x-axis for the event graph
+//
+Float_t *MHGausEvents::CreateEventXaxis(Int_t n)
 {
 
@@ -535,4 +535,24 @@
     for (Int_t i=0;i<n;i++)
       xaxis[i] = (Float_t)i;
+
+  return xaxis;
+                 
+}
+
+// -----------------------------------------------------------------------------
+// 
+// Create the x-axis for the event graph
+//
+Float_t *MHGausEvents::CreatePSDXaxis(Int_t n)
+{
+
+  Float_t *xaxis = new Float_t[n];
+
+  if (fEventFrequency)
+    for (Int_t i=0;i<n;i++)
+      xaxis[i] = 0.5*(Float_t)i*fEventFrequency/n;
+  else
+    for (Int_t i=0;i<n;i++)
+      xaxis[i] = 0.5*(Float_t)i/n;
 
   return xaxis;
Index: trunk/MagicSoft/Mars/mcalib/MHGausEvents.h
===================================================================
--- trunk/MagicSoft/Mars/mcalib/MHGausEvents.h	(revision 3607)
+++ trunk/MagicSoft/Mars/mcalib/MHGausEvents.h	(revision 3608)
@@ -65,5 +65,6 @@
   void DrawPowerSpectrum(TVirtualPad &pad, Int_t i);  // Draw a graph of the array fPowerSpectrum and the hist fHPowerProbability
   
-  Float_t *CreateXaxis(Int_t n);      //   Create an x-axis for the TGraphs
+  Float_t *CreateEventXaxis(Int_t n);              //   Create an x-axis for the Event TGraphs
+  Float_t *CreatePSDXaxis(Int_t n);                //   Create an x-axis for the PSD TGraphs
 
 public:
